@@ -1,3 +1,22 @@
+#' Calculate the edge posterior probabilities for each timepoint.
+#' 
+#' This function calculates the marginal posterior edge probabilities of the
+#' network at each timepoint.
+#' 
+#' 
+#' @param network.samples Collection of network and changepoint samples of the
+#' MCMC simulation, as obtained by \code{\link{EDISON.run}},
+#' \code{\link{runDBN}}.
+#' @param cps Changepoint vector.
+#' @param numNodes Number of nodes in the network.
+#' @return A list of length equal to the number of timepoints, where each entry
+#' contains a matrix of size NumNodes by NumNodes with the marginal posterior
+#' edge probabilities of the network at this timepoint.
+#' @author Frank Dondelinger
+#' @seealso \code{\link{calculateEdgeProbabilities}},
+#' 
+#' \code{\link{calculateEdgeProbabilitiesSegs}}
+#' @export calculateEdgeProbabilitiesTimePoints
 calculateEdgeProbabilitiesTimePoints <- 
   function(network.samples, cps, numNodes) {
   sampled = network.samples[[1]]$sampled 
@@ -11,7 +30,7 @@ calculateEdgeProbabilitiesTimePoints <-
     prob.networks[[seg]] = matrix(0, numNodes, numNodes)
   }
   
-  for(sample.i in 1:(length(sampled)-1)) {
+  for(sample.i in 1:length(sampled)) {
     for(target in 1:numNodes) {
       cps.temp = network.samples[[target]]$cp_samples[sample.i,]
       max.cp   = length(cps.temp) - 1
