@@ -22,13 +22,13 @@
 dinvgamma <-
 function(x, shape, scale=1, log=FALSE) {
 
-    dens = shape * log(scale) - lgamma(shape) - (shape + 1) * log(x) 
+    log.dens = shape * log(scale) - lgamma(shape) - (shape + 1) * log(x) 
             - (scale/x)
   
     if(!log) {
-      return(dens)
+      return(exp(log.dens))
     } else {
-      return(log(dens))
+      return(log.dens)
     }
 }
 
